@@ -635,9 +635,32 @@ void Main::openTools(QXmlStreamReader &xml, QString config_name)
 	}
 }
 
+void Main::openFilesToEdit(QStringList files)
+{
+	if(files.isEmpty()) return;
+	BaseWidget *bw=(BaseWidget*)session.getFirstTool(EDITOR);
+	if(bw==NULL) bw=createTool(EDITOR, NULL);
+	Editor *editor=(Editor*)bw;
+	editor->loadFiles(files);
+	editor->show();
+}
+
 #include <QSplashScreen>
 #include <QTimer>
 
+/** Process comand line looking for files to open.
+ */
+static QStringList command_line_find_files(int argn, char *argv[])
+{
+	QStringList files;
+	
+	for(int i=1;i<argn;i++)
+	{
+		files.append(argv[i]);
+	}
+	
+	return files;
+}
 
 int main(int argn, char *argv[])
 {
@@ -656,30 +679,45 @@ int main(int argn, char *argv[])
 	QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
 
 	// Qt translations
+	QString locales=QLocale::system().name();
+	//if(locales.length()>2)
+	//{
+	//	locales.resize(2);
+	//}
+		
 	if(qtTranslator.load("qt_" + QLocale::system().name(),
 			     "/usr/share/qt4/translations"))
 	{
 	  a.installTranslator(&qtTranslator);
 	  printf("[main()] Loaded QT Translation file for locale '%s'.\n",
 		 QLocale::system().name().toLocal8Bit().data());
-	}else
+	}
+	else
+	{
 	  printf("[main()] Error loading the QT Translation file for locale '%s'.\n",
 		 QLocale::system().name().toLocal8Bit().data());
+	}
 
 	// QtOctave translations
-	if(qtoctaveTranslator.load("qtoctave_" + QLocale::system().name(), LANG_PATH))
+	if(qtoctaveTranslator.load("qtoctave_" + locales, LANG_PATH))
 	{
 	  a.installTranslator(&qtoctaveTranslator);
 	  printf("[main()] Loaded translation file for locale '%s'.\n",
 		 QLocale::system().name().toLocal8Bit().data());
-	}else
-	  printf("[main()] Error loading the translation file for locale '%s'.\n",
-		 QLocale::system().name().toLocal8Bit().data());
+	}
+	else
+	{
+	  printf("[main()] Error loading the translation file for locale '%s'. Not found in %s \n",
+		 locales.toLocal8Bit().data(), LANG_PATH);
+	}
 
 	// Load
 	a.processEvents();
 	Main m;
-
+	
+	//Open command line files
+	m.openFilesToEdit(command_line_find_files(argn,argv));
+	
 	//Destroy splash screnn
 	splash->finish(m.mainWindowWidget());
 	delete splash;
